use "asclogit", clear
set more off




*** aus Manual "asclogit postestimation"

/*
Saved results
estat mfx saves the following in r():
Scalars
r(pr_alt) scalars containing the computed probability of each alternative evaluated at the value that is
          labeled X in the table output. Here alt are the labels in the macro e(alteqs).
Matrices
r(alt)     matrices containing the computed marginal effects and associated statistics. There is one matrix
           for each alternative, where alt are the labels in the macro e(alteqs). Column 1 of each
           matrix contains the marginal effects; column 2, their standard errors; column 3, their z
           statistics; and columns 4 and 5 ("well, I think, it is 5 & 6"), the confidence intervals. 
           Column 6 contains the values of the independent variables used to compute the probabilities r(pr_alt).
*/


asclogit kan per B6 sumb8 B11 eigenbudget spid, casevars(ost know) case(lfd) alternatives(type) base(1)
drop if !e(sample)
estat summarize, equation labels
matrix list e(b)




*realistic scenario
bysort type: sum B11
bysort type: sum eigenbudget
bysort type: sum B6
bysort type: sum sumb8
bysort type: sum per

*include fundamental uncertainty
preserve 
set seed 1234
drawnorm MG_b1-MG_b18, n(1000) means(e(b)) cov(e(V)) clear 
postutil clear


postfile mypost prob_hatc prob_hatc5 prob_hats prob_hatg prob_hatf prob_hatl loc hic loc5 hic5 los his log hig lof hif lol hil eigenc  using sim , replace
            noisily display "start"


            
***********************************************************************
* Start loop.  Let `a' be the causal variable of interest and let this*
* run from min to max in the desired increments.                      *
***********************************************************************
                            

local a=0 
while `a' <= 5 { 

{
 
*Define scenario
scalar h_perc         = `a' 
scalar h_B6c          = 2.680328 
scalar h_sumb8c       = 2.221527 
scalar h_B11c         = 54.91803 
scalar h_eigenbudgetc = 47.59467
scalar h_spidc        = 0 
scalar h_spidc5        = 5 


scalar h_pers         = .9631902 
scalar h_B6s          = 3.93865
scalar h_sumb8s       = 2.576687 
scalar h_B11s         = 39.44867 
scalar h_eigenbudgets = 20.38419
scalar h_spids        = 0 

 
scalar h_perg         = .4127907 
scalar h_B6g          = 6.924419
scalar h_sumb8g       = 2.110465 
scalar h_B11g         = 6.433721 
scalar h_eigenbudgetg = 2.186395
scalar h_spidg        = 0 

scalar h_perf         = .6045198 
scalar h_B6f          = 6.344633
scalar h_sumb8f       = 2.101695 
scalar h_B11f         = 7.324294 
scalar h_eigenbudgetf = 4.005819 
scalar h_spidf        = 0 

scalar h_perl         = .2814815 
scalar h_B6l          = 7.303704
scalar h_sumb8l       = 1.777778 
scalar h_B11l         = 6.629259 
scalar h_eigenbudgetl = 3.021296
scalar h_spidl        = 0 


scalar h_Sost        = 0 
scalar h_Sknow       = 1.381014
scalar h_S_cons      = 1 
scalar h_Gost        = 0 
scalar h_Gknow       = h_Sknow
scalar h_G_cons      = 1
scalar h_Fost        = 0 
scalar h_Fknow       = h_Sknow
scalar h_F_cons      = 1
scalar h_Lost        = 0 
scalar h_Lknow       = h_Sknow
scalar h_L_cons      = 1


#delimit ;

generate Vcdu =  exp(MG_b1 *h_perc   +      
                     MG_b2 *h_B6c     +    
                     MG_b3 *h_sumb8c   +    
                     MG_b4 *h_B11c       + 
                     MG_b5 *h_eigenbudgetc +
                     MG_b6 *h_spidc) ;

generate Vcdu5 =  exp(MG_b1 *h_perc   +      
                     MG_b2 *h_B6c     +    
                     MG_b3 *h_sumb8c   +    
                     MG_b4 *h_B11c       + 
                     MG_b5 *h_eigenbudgetc +
                     MG_b6 *h_spidc5) ;
 
generate Vspd =  exp(MG_b1 *h_pers   +      
                 MG_b2 *h_B6s     +    
                 MG_b3 *h_sumb8s   +    
                 MG_b4 *h_B11s     +  
                 MG_b5 *h_eigenbudgets +
                 MG_b6 *h_spids       +
                 MG_b7 *h_Sost        +
                 MG_b8 *h_Sknow      +
                 MG_b9 *h_S_cons);

generate Vb90 =  exp(MG_b1 *h_perg   +      
                 MG_b2 *h_B6g     +    
                 MG_b3 *h_sumb8g   +    
                 MG_b4 *h_B11g       + 
                 MG_b5 *h_eigenbudgetg +
                 MG_b6 *h_spidg       +
                 MG_b10*h_Gost        +
                 MG_b11*h_Gknow      +
                 MG_b12*h_G_cons);

generate Vfdp =  exp(MG_b1 *h_perf   +      
                 MG_b2 *h_B6f     +    
                 MG_b3 *h_sumb8f   +    
                 MG_b4 *h_B11f        +
                 MG_b5 *h_eigenbudgetf +
                 MG_b6 *h_spidf      +
                 MG_b13*h_Fost        +
                 MG_b14*h_Fknow      +
                 MG_b15*h_F_cons);

generate Vlin =  exp(MG_b1 *h_perl   +      
                 MG_b2 *h_B6l     +    
                 MG_b3 *h_sumb8l   +    
                 MG_b4 *h_B11l        +
                 MG_b5 *h_eigenbudgetl +
                 MG_b6 *h_spidl       +
                 MG_b16*h_Lost        +
                 MG_b17*h_Lknow      +
                 MG_b18*h_L_cons);
     

#delimit cr
gen prob_c5 = Vcdu5 / (Vcdu5 + Vspd + Vb90 + Vfdp + Vlin) 
gen prob_c = Vcdu / (Vcdu + Vspd + Vb90 + Vfdp + Vlin) 
gen prob_s = Vspd / (Vcdu + Vspd + Vb90 + Vfdp + Vlin) 
gen prob_g = Vb90 / (Vcdu + Vspd + Vb90 + Vfdp + Vlin) 
gen prob_f = Vfdp / (Vcdu + Vspd + Vb90 + Vfdp + Vlin) 
gen prob_l = Vlin / (Vcdu + Vspd + Vb90 + Vfdp + Vlin) 

egen probhatc5 = mean(prob_c5) 
egen probhatc = mean(prob_c) 
egen probhats = mean(prob_s) 
egen probhatg = mean(prob_g) 
egen probhatf = mean(prob_f) 
egen probhatl = mean(prob_l) 


tempname prob_hatc prob_hatc5 prob_hats prob_hatg prob_hatf prob_hatl loc hic loc5 hic5 los his log hig lof hif lol hil eigenc

    scalar `prob_hatc'=probhatc
    scalar `prob_hatc5'=probhatc5
    scalar `prob_hats'=probhats
    scalar `prob_hatg'=probhatg
    scalar `prob_hatf'=probhatf
    scalar `prob_hatl'=probhatl

    _pctile prob_c, p(2.5,97.5) 
    scalar `loc' = r(r1)
    scalar `hic' = r(r2)  

    _pctile prob_c5, p(2.5,97.5) 
    scalar `loc5' = r(r1)
    scalar `hic5' = r(r2)  

    _pctile prob_s, p(2.5,97.5) 
    scalar `los' = r(r1)
    scalar `his' = r(r2)  

    _pctile prob_g, p(2.5,97.5) 
    scalar `log' = r(r1)
    scalar `hig' = r(r2)  

    _pctile prob_f, p(2.5,97.5) 
    scalar `lof' = r(r1)
    scalar `hif' = r(r2)  

    _pctile prob_l, p(2.5,97.5) 
    scalar `lol' = r(r1)
    scalar `hil' = r(r2)  


    scalar `eigenc'=h_eigenbudgetc 

* Beware! Use same order as before!
post mypost  (`prob_hatc') (`prob_hatc5') (`prob_hats') (`prob_hatg')  (`prob_hatf')  (`prob_hatl') (`loc') (`hic') (`loc5') (`hic5') (`los') (`his') (`log') (`hig') (`lof') (`hif') (`lol') (`hil')  (`eigenc') 
    


}      

    drop V*  prob_* probhat* 

    local a=`a'+ 1
    display "." _c
    } 


postclose mypost



use sim, clear


* Length X-axis;
gen xaxis = _n-1

gen cdu = (hic + loc)/2
gen cdu5 = (hic5 + loc5)/2


#delimit ;
twoway
rspike loc hic xaxis || 
scatter cdu xaxis, sort mstyle(p1) mfcolor(white) || 
rspike loc5 hic5 xaxis || 
scatter cdu5 xaxis, sort mstyle(p1) msize(.8)
, legend(off) ytitle("Pr( Recall CDU/CSU Candidate )", color(black)) 
yscale(lcolor(none) titlegap(2) range(0 1)) ylabel(0(1)1,  ticks angle(0)) 
xtitle("Degree of Exposure to Candidate's Campaign", color(black) alignment(bottom )) xscale(titlegap(3) ) 
xlabel(0(1)5, ticks labels) xscale(lcolor(none))
text(  .9 0.05 "Strong Identification with C's Party", place(r) size(small) ) 
text( .12 0.05 "No Identification with C's Party", place(r) size(small) ) 
scheme(s1mono) saving(cdurecall, replace)
;
#delimit cr

graph export cdurecall.pdf, replace
graph export cdurecall.tif, replace
graph export cdurecalls.png, replace
graph export cdurecall.eps, replace preview(on)




exit

